/**
 * This file demonstrates the ability to command settings to a group.
 */

#include <stdio.h>

#include "hebi.h"
#include "util/lookup_helpers.c"

int main(int argc, char* argv[])
{
  // Try and get the requested group.
  HebiGroupPtr group = getGroupFromArgs(argc, argv);
  if (group == NULL)
  {
    hebiCleanup();
    return -1;
  }

  int numModules = hebiGroupGetSize(group);

  if (numModules == 0)
  {
    printf("Group has no modules!\n");
    hebiGroupRelease(group);
    hebiCleanup();
    return -1;
  }

  // Get a new name for the first module:
  printf("Enter a new name for this module.\n");
  char buf[50]; // Hold up to 49 characters!
  char *p = fgets(buf, 50, stdin);
  while (p == NULL || strlen(buf) == 0)
  {
    printf("No input detected.  Type a name, and try again.\n");
    p = fgets(buf, 50, stdin);
  }

  // Remove any trailing newline character.
  size_t last = strlen(buf) - 1;
  if (buf[last] == '\n')
    buf[last--] = '\0';

  // Create a command object; this can be sent to the group
  HebiGroupCommandPtr command = hebiGroupCommandCreate(numModules);
  if (command == NULL)
  {
    printf("Could not create command object!\n");
    hebiGroupRelease(group);
    hebiCleanup();
    return -1;
  }

  // Set a new name for the first module:
  HebiCommandPtr module_cmd = hebiGroupCommandGetModuleCommand(command, 0);
  hebiCommandSetString(module_cmd, HebiCommandStringName, buf, &last);

  // Mark that settings should be persisted across reboots.
  int flag = 1;
  hebiCommandSetFlag(module_cmd, HebiCommandFlagSaveCurrentSettings, flag);

  printf("Setting and saving new module name. Restart and verify name has been reset.\n");
  long timeout_ms = 100;
  if (hebiGroupSendCommandWithAcknowledgement(group, command, timeout_ms) == 0)
  {
    printf("Got acknowledgement.\n");
  }
  else
  {
    printf("Did not receive acknowledgement!\n");
  }

  // We must release the resources back to the library when done!
  hebiGroupCommandRelease(command);
  hebiGroupRelease(group);
  hebiCleanup();
  return 0;
}
