/**
 * This file demonstrates the ability to command settings to a group.
 */

#include <stdio.h>

#include "hebi.h"
#include "util/lookup_helpers.c"

int main(int argc, char* argv[])
{
  // Try and get the requested group.
  HebiGroupPtr group = getGroupFromArgs(argc, argv);
  if (group == NULL)
  {
    hebiCleanup();
    return -1;
  }

  int numModules = hebiGroupGetSize(group);

  // Create a command object; this can be sent to the group
  HebiGroupCommandPtr command = hebiGroupCommandCreate(numModules);
  if (command == NULL)
  {
    printf("Could not create command object!\n");
    hebiGroupRelease(group);
    hebiCleanup();
    return -1;
  }

  // Set the name for all the modules
  char num_str[12]; // Temp variable to hold the name.  Guaranteed to be plenty big for our groups.
  int module_index;
  for (module_index = 0; module_index < numModules; module_index++)
  {
    // We get the command for this particular module
    HebiCommandPtr module_cmd = hebiGroupCommandGetModuleCommand(command, module_index);
    // Set the name for this module, based on its index within the group.
    // (Note -- we do not save this value, so upon module reset this will be
    // cleared)
    size_t len = sprintf(num_str, "%d", module_index);
    hebiCommandSetString(module_cmd, HebiCommandStringName, num_str, &len);
  }

  long timeout_ms = 100;
  if (hebiGroupSendCommandWithAcknowledgement(group, command, timeout_ms) == 0)
  {
    printf("Got acknowledgement.\n");
  }
  else
  {
    printf("Did not receive acknowledgement!\n");
  }

  // We must release the resources back to the library when done!
  hebiGroupCommandRelease(command);
  hebiGroupRelease(group);
  hebiCleanup();
  return 0;
}
