/**
 * This file demonstrates the ability to get feedback from a group containing
 * I/O boards.
 */

#include <stdio.h>

#include "hebi.h"
#include "util/feedback_print_helpers.c"
#include "util/lookup_helpers.c"
#include "util/hebi_util.h"

int main(int argc, char* argv[])
{
  // Try and get the requested group.
  HebiGroupPtr group = getGroupFromArgs(argc, argv);
  if (group == NULL)
  {
    hebiCleanup();
    return -1;
  }

  // Create a group feedback object; this will be filled in during the request.
  HebiGroupFeedbackPtr feedback =
    hebiGroupFeedbackCreate(hebiGroupGetSize(group));
  if (feedback == NULL)
  {
    printf("Could not create feedback object!\n");
    hebiGroupRelease(group);
    hebiCleanup();
    return -1;
  }

  // In a loop, send requests for feedback to the group and wait for responses.
  long timeout_ms = 1000;
  float period_s = 0.25f;
  int i;
  for (i = 0; i < 100; i++)
  {
    HebiFeedbackPtr moduleFeedback = hebiGroupFeedbackGetModuleFeedback(feedback, 0);
    hebiGroupSendFeedbackRequest(group);
    float ioPin;
    if (hebiGroupGetNextFeedback(group, feedback, timeout_ms) == 0 &&
        hebiFeedbackGetIoPinFloat(moduleFeedback, HebiFeedbackIoBankA, 1, &ioPin) == HebiStatusSuccess)
    {
      printf("%f\n", ioPin);
    }
    else
      printf("Received no feedback from group!\n");
    hebi_sleep_ms(period_s * 1000);
  }

  // We must release the resources back to the library when done!
  hebiGroupFeedbackRelease(feedback);
  hebiGroupRelease(group);
  hebiCleanup();
  return 0;
}
