/**
 * This file demonstrates the ability to get feedback from a group.
 */

#include <stdio.h>

#include "hebi.h"
#include "util/feedback_print_helpers.c"
#include "util/lookup_helpers.c"
#include "util/hebi_util.h"

int main(int argc, char* argv[])
{
  // Try and get the requested group.
  HebiGroupPtr group = getGroupFromArgs(argc, argv);
  if (group == NULL)
  {
    hebiCleanup();
    return -1;
  }

  // Create a group feedback object; this will be filled in during the request.
  HebiGroupFeedbackPtr feedback =
    hebiGroupFeedbackCreate(hebiGroupGetSize(group));
  if (feedback == NULL)
  {
    printf("Could not create feedback object!\n");
    hebiGroupRelease(group);
    hebiCleanup();
    return -1;
  }

  // In a loop, send requests for feedback to the group and wait for responses.
  long timeout_ms = 1000;
  float period_s = 0.25f;
  int i;
  printf("Sending requests in main thread at 4Hz\n");
  for (i = 0; i < 20; i++)
  {
    hebiGroupSendFeedbackRequest(group);
    hebi_sleep_ms(1000.0f * period_s);
    if (hebiGroupGetNextFeedback(group, feedback, timeout_ms) == 0)
      print_group_feedback(feedback);
    else
      printf("Received no feedback from group!\n");
  }

  // Or, set the feedback frequency so requests are sent in the background,
  // and then just call the request as desired.
  hebiGroupSetFeedbackFrequencyHz(group, 8);
  printf("Sending requests in background at 8Hz\n");
  for (i = 0; i < 20; i++)
  {
    if (hebiGroupGetNextFeedback(group, feedback, timeout_ms) == 0)
      print_group_feedback(feedback);
    else
      printf("Received no feedback from group!\n");
  }
  hebiGroupSetFeedbackFrequencyHz(group, 0);

  // We must release the resources back to the library when done!
  hebiGroupFeedbackRelease(feedback);
  hebiGroupRelease(group);
  hebiCleanup();
  return 0;
}
